==> jc-1.4.0.tar.gz: soot/baf/WordType.h <==
// public class soot.baf.WordType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class cd2b6570b5d12b2c soot_baf_WordType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_baf_WordType_H_
#define _JC_soot_baf_WordType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_baf_WordType$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_WordType$sub_refs	_jc_soot_baf_WordType$sub_refs;
typedef struct _jc_soot_baf_WordType$sub_nonrefs	_jc_soot_baf_WordType$sub_nonrefs;
typedef struct _jc_soot_baf_WordType$refs	_jc_soot_baf_WordType$refs;
typedef struct _jc_soot_baf_WordType$nonrefs	_jc_soot_baf_WordType$nonrefs;
typedef struct _jc_soot_baf_WordType$object	_jc_soot_baf_WordType$object;

typedef const struct _jc_soot_baf_WordType$vmethods	_jc_soot_baf_WordType$vmethods;
typedef const struct _jc_soot_baf_WordType$vtable	_jc_soot_baf_WordType$vtable;
typedef const struct _jc_soot_baf_WordType$vtype	_jc_soot_baf_WordType$vtype;

// Constructors
extern void _jc_soot_baf_WordType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_baf_WordType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_object *);
extern jboolean _jc_soot_baf_WordType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_baf_WordType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_baf_WordType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_WordType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_WordType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_WordType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_WordType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_baf_WordType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_baf_WordType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_baf_WordType$object *_jc_soot_baf_WordType$method$v$1ce8aa4a2a40d1b4(_jc_env *);

// Virtual methods structure
struct _jc_soot_baf_WordType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_baf_WordType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_WordType$object *);
};

// Vtable
struct _jc_soot_baf_WordType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_baf_WordType$vmethods	soot_baf_WordType;
};

// Vtype
struct _jc_soot_baf_WordType$vtype {
	_jc_type			type;
	_jc_soot_baf_WordType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_WordType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_WordType$refs {
    _jc_soot_baf_WordType$sub_refs	soot_baf_WordType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_WordType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_WordType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_baf_WordType$sub_nonrefs	soot_baf_WordType;
};

// Object instance structure
struct _jc_soot_baf_WordType$object {
	_jc_soot_baf_WordType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_WordType$vtype	*vtype;
	_jc_soot_baf_WordType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_WordType$vtype _jc_soot_baf_WordType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_WordType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_WordType$class_object;

#endif	/* _JC_soot_baf_WordType_H_ */

==> jc-1.4.6.tar.gz: soot/baf/WordType.h <==
// public class soot.baf.WordType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class cd2b6570b5d12b2c soot_baf_WordType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_baf_WordType_H_
#define _JC_soot_baf_WordType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_baf_WordType$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_WordType$sub_refs	_jc_soot_baf_WordType$sub_refs;
typedef struct _jc_soot_baf_WordType$sub_nonrefs	_jc_soot_baf_WordType$sub_nonrefs;
typedef struct _jc_soot_baf_WordType$refs	_jc_soot_baf_WordType$refs;
typedef struct _jc_soot_baf_WordType$nonrefs	_jc_soot_baf_WordType$nonrefs;
typedef struct _jc_soot_baf_WordType$object	_jc_soot_baf_WordType$object;

typedef const struct _jc_soot_baf_WordType$vmethods	_jc_soot_baf_WordType$vmethods;
typedef const struct _jc_soot_baf_WordType$vtable	_jc_soot_baf_WordType$vtable;
typedef const struct _jc_soot_baf_WordType$vtype	_jc_soot_baf_WordType$vtype;

// Constructors
extern void _jc_soot_baf_WordType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_WordType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_baf_WordType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_WordType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_baf_WordType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_WordType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_WordType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_WordType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_WordType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_baf_WordType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_baf_WordType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_baf_WordType$object *_jc_soot_baf_WordType$method$v$1ce8aa4a2a40d1b4(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_baf_WordType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_baf_WordType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_baf_WordType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_WordType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_WordType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_baf_WordType$vmethods	soot_baf_WordType;
};

// Vtype
struct _jc_soot_baf_WordType$vtype {
	_jc_type			type;
	_jc_soot_baf_WordType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_WordType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_WordType$refs {
    _jc_soot_baf_WordType$sub_refs	soot_baf_WordType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_WordType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_WordType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_baf_WordType$sub_nonrefs	soot_baf_WordType;
};

// Object instance structure
struct _jc_soot_baf_WordType$object {
	_jc_soot_baf_WordType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_WordType$vtype	*vtype;
	_jc_soot_baf_WordType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_WordType$vtype _jc_soot_baf_WordType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_WordType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_WordType$class_object;

#endif	/* _JC_soot_baf_WordType_H_ */
